@@ -4,22 +4,24 @@
 
 #include <QApplication>
 #include <QCommandLineParser>
-#include <QQmlApplicationEngine>
-#include <QtQml>
-#include <QUrl>
 #include <QIcon>
+#include <QQmlApplicationEngine>
+#include <QUrl>
+#include <QtQml>
 
+#include <KAboutData>
 #include <KLocalizedContext>
 #include <KLocalizedString>
-#include <KAboutData>
 
 #include "fontlistmodel.h"
-#include "terminalsettings.h"
 #include "savedcommandsmodel.h"
-#include "terminaltabmodel.h"
-#include "version.h"
-#include "util.h"
 #include "shellcommand.h"
+#include "terminalsettings.h"
+#include "terminaltabmodel.h"
+#include "util.h"
+#include "version.h"
+
+#include <KonsoleQML.h>
 
 constexpr auto URI = "org.kde.qmlkonsole";
 
@@ -44,6 +46,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
         return new ShellCommand();
     });
 
+    KonsoleQML::registerTypes("org.kde.konsoleqml");
+
     QObject::connect(TerminalSettings::self(), &TerminalSettings::configChanged, QApplication::instance(), [] {
         TerminalSettings::self()->save();
         qDebug() << "saving config";
